command

package
v1.0.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 17, 2026 License: MIT Imports: 9 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func DetachForAsync added in v1.0.0

func DetachForAsync[P types.ParameterView](cmd types.Command[P]) types.Command[P]

func ParseInto added in v1.0.0

func ParseInto[P types.ParameterView](ctx *context.Context[P], dest *types.Command[P]) error

ParseFromReader parses a Photon command from a parser.Reader. It first reads the 12-byte command header, validates the length field, then reads the remaining payload data.

Returns an error if:

  • The header cannot be read
  • The length field is smaller than the header size (invalid)
  • The payload data cannot be fully read

The returned Command struct contains all header fields and the raw payload in the Data field. For SendReliable commands, the Data can be further parsed using the reliable package.

Types

This section is empty.

Directories

Path Synopsis

Jump to