session

package
v0.0.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 9, 2026 License: MIT Imports: 8 Imported by: 0

Documentation

Overview

Package session provides parsing for Photon Protocol session layer packets. The session layer is the outermost protocol layer, containing session metadata and one or more commands.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Parse

func Parse[P types.ParameterView](ctx *context.Context[P], out *types.Session) error

Parse parses a Photon session packet from a parser.Reader. This function reads the session header, then iterates through and parses each command as specified by the CommandCount field.

Returns a Session struct with all fields populated including the Commands slice, or an error if any part of parsing fails.

Types

type Session

type Session[P types.ParameterView] struct {
	types.Session
}

Jump to