Documentation
¶
Overview ¶
Package session provides parsing for Photon Protocol session layer packets. The session layer is the outermost protocol layer, containing session metadata and one or more commands.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Parse ¶
Parse parses a Photon session packet from a parser.Reader. This function reads the session header, then iterates through and parses each command as specified by the CommandCount field.
Returns a Session struct with all fields populated including the Commands slice, or an error if any part of parsing fails.
Types ¶
Click to show internal directories.
Click to hide internal directories.