session

package
v1.0.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 17, 2026 License: MIT Imports: 7 Imported by: 0

Documentation

Overview

Package session provides parsing for Photon Protocol session layer packets. The session layer is the outermost protocol layer, containing session metadata and one or more commands.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ParseInto added in v1.0.0

func ParseInto[P types.ParameterView](ctx *context.Context[P], dest *types.Session[P]) error

ParseInto parses a Photon session packet from a parser.Reader. This function reads the session header, then iterates through and parses each command as specified by the CommandCount field.

Returns an error if any part of parsing fails.

Types

This section is empty.

Jump to